{
    "class": "CommandLineTool",
    "label": "MaxQuant",
    "doc": "MaxQuant is a quantitative proteomics software package designed for analyzing large mass-spectrometric data sets. It is specifically aimed at high-resolution MS data. Several labeling techniques as well as label-free quantification are supported. MaxQuant is freely available and can be downloaded from https://maxquant.org.",
    "requirements": [
        {
            "listing": [
                {
                    "entry": "$(inputs.raw_data_dir)",
                    "writable": true
                },
                {
                    "entryname": "script.sh",
                    "entry": "#!/bin/bash\necho \"Running mqpar.xml conversion\"\nmono /MaxQuant_2.4.0.0/bin/MaxQuantCmd.exe $@\necho \"Running MaxQuant\"\nmono /MaxQuant_2.4.0.0/bin/MaxQuantCmd.exe $HOME/changed_mqpar.xml"
                }
            ],
            "class": "InitialWorkDirRequirement"
        },
        {
            "class": "InlineJavascriptRequirement"
        }
    ],
    "hints": [
        {
            "dockerPull": "docker-registry.wur.nl/m-unlock/docker/maxquant:2.4.2.0",
            "class": "DockerRequirement"
        },
        {
            "packages": [
                {
                    "version": [
                        "3.1.426"
                    ],
                    "specs": [
                        "https://anaconda.org/conda-forge/dotnet"
                    ],
                    "package": "dotnet"
                },
                {
                    "version": [
                        "6.12.0.90"
                    ],
                    "specs": [
                        "https://anaconda.org/conda-forge/mono"
                    ],
                    "package": "mono"
                }
            ],
            "class": "SoftwareRequirement"
        }
    ],
    "baseCommand": [
        "bash",
        "-x",
        "script.sh"
    ],
    "inputs": [
        {
            "type": "Directory",
            "inputBinding": {
                "position": 3,
                "prefix": ""
            },
            "doc": "Directory containing the required FASTA files as described in the mqpar.xml file.",
            "label": "FASTA directory",
            "id": "#main/fasta"
        },
        {
            "type": "File",
            "inputBinding": {
                "position": 1,
                "prefix": ""
            },
            "doc": "MaxQuant parameter file (mqpar.xml)",
            "label": "MaxQuant parameter file",
            "id": "#main/mqpar"
        },
        {
            "type": "Directory",
            "inputBinding": {
                "position": 4,
                "prefix": ""
            },
            "doc": "Directory containing raw data files",
            "label": "Directory containing raw data files",
            "id": "#main/raw_data_dir"
        }
    ],
    "arguments": [
        {
            "valueFrom": "changed_mqpar.xml",
            "position": 2,
            "prefix": "--changeFolder=",
            "separate": false,
            "shellQuote": false
        }
    ],
    "stdout": "MaxQuant.log",
    "id": "#main",
    "https://schema.org/author": [
        {
            "class": "https://schema.org/Person",
            "https://schema.org/identifier": "https://orcid.org/0000-0001-8172-8981",
            "https://schema.org/email": "mailto:jasper.koehorst@wur.nl",
            "https://schema.org/name": "Jasper Koehorst"
        },
        {
            "class": "https://schema.org/Person",
            "https://schema.org/identifier": "https://orcid.org/0000-0001-9524-5964",
            "https://schema.org/email": "mailto:bart.nijsse@wur.nl",
            "https://schema.org/name": "Bart Nijsse"
        }
    ],
    "https://schema.org/citation": "https://m-unlock.nl",
    "https://schema.org/codeRepository": "https://gitlab.com/m-unlock/cwl",
    "https://schema.org/dateCreated": "2023-05-22",
    "https://schema.org/license": "https://spdx.org/licenses/Apache-2.0",
    "https://schema.org/copyrightHolder": "UNLOCK - Unlocking Microbial Potential",
    "outputs": [
        {
            "type": "File",
            "label": "Log",
            "doc": "Log file recording the core steps of MaxBin algorithm",
            "outputBinding": {
                "glob": "MaxQuant.log"
            },
            "id": "#main/log"
        },
        {
            "type": "File",
            "label": "New MaxQuant parameter file",
            "doc": "The newly generated MaxQuant parameter file",
            "outputBinding": {
                "glob": "changed_mqpar.xml"
            },
            "id": "#main/mqpar"
        },
        {
            "type": "Directory",
            "label": "MaxQuant result directory",
            "doc": "The result directory of a MaxQuant run",
            "outputBinding": {
                "glob": "$(inputs.raw_data_dir.basename)/combined"
            },
            "id": "#main/output"
        }
    ],
    "cwlVersion": "v1.2",
    "$namespaces": {
        "s": "https://schema.org/"
    }
}